@@ -7,7 +7,7 @@ def test_word():
 
 
 def test_pdf():
-    office.pdf.pdf_add_watermark()
+    office.pdf.add_watermark()
 
 
 test_pdf()
